@@ -14,16 +14,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-from oslo_service import service as os_service
+import cotyledon
+from cotyledon import oslo_config_glue
 
 from ceilometer import notification
 from ceilometer import service
 
-CONF = cfg.CONF
-
 
 def main():
-    service.prepare_service()
-    os_service.launch(CONF, notification.NotificationService(),
-                      workers=CONF.notification.workers).wait()
+    conf = service.prepare_service()
+
+    sm = cotyledon.ServiceManager()
+    sm.add(notification.NotificationService,
+           workers=conf.notification.workers, args=(conf,))
+    oslo_config_glue.setup(sm, conf)
+    sm.run()
