@@ -11,6 +11,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from distutils import version
+
 from gnocchiclient import client
 from gnocchiclient import exceptions as gnocchi_exc
 import keystoneauth1.session
@@ -21,12 +23,10 @@ from ceilometer import keystone_client
 LOG = log.getLogger(__name__)
 
 
-def get_gnocchiclient(conf, timeout_override=False):
-    group = conf.dispatcher_gnocchi.auth_section
-    timeout = (None if (not conf.dispatcher_gnocchi.request_timeout or
-                        timeout_override)
-               else conf.dispatcher_gnocchi.request_timeout)
-    session = keystone_client.get_session(conf, group=group, timeout=timeout)
+def get_gnocchiclient(conf, request_timeout=None):
+    group = conf.gnocchi.auth_section
+    session = keystone_client.get_session(conf, group=group,
+                                          timeout=request_timeout)
     adapter = keystoneauth1.session.TCPKeepAliveAdapter(
         pool_maxsize=conf.max_parallel_requests)
     session.mount("http://", adapter)
@@ -184,11 +184,34 @@ resources_update_operations = [
                         "controller": {"type": "string", "min_length": 0,
                                        "max_length": 255, "required": True}}
      }]},
+    {"desc": "add volume provider resource type",
+     "type": "create_resource_type",
+     "resource_type": "volume_provider",
+     "data": [{
+         "attributes": {}
+     }]},
+    {"desc": "add volume provider pool resource type",
+     "type": "create_resource_type",
+     "resource_type": "volume_provider_pool",
+     "data": [{
+         "attributes": {"provider": {"type": "string", "min_length": 0,
+                                     "max_length": 255, "required": True}}
+     }]},
 ]
 
+# NOTE(sileht): We use LooseVersion because pbr can generate invalid
+# StrictVersion like 9.0.1.dev226
+REQUIRED_VERSION = version.LooseVersion("4.0.0")
+
 
 def upgrade_resource_types(conf):
-    gnocchi = get_gnocchiclient(conf, True)
+    gnocchi = get_gnocchiclient(conf)
+
+    gnocchi_version = version.LooseVersion(gnocchi.build.get())
+    if gnocchi_version < REQUIRED_VERSION:
+        raise Exception("required gnocchi version is %s, got %s",
+                        REQUIRED_VERSION, gnocchi_version)
+
     for name, attributes in resources_initial.items():
         try:
             gnocchi.resource_type.get(name=name)
