@@ -16,21 +16,13 @@
 notification events.
 """
 
-from oslo_config import cfg
 from oslo_log import log
-import oslo_messaging as messaging
 
-from ceilometer.agent import plugin_base
+from ceilometer.pipeline import sample as endpoint
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
 
-OPTS = [
-    cfg.StrOpt('ironic_exchange',
-               default='ironic',
-               help='Exchange name for Ironic notifications.'),
-]
-
 
 # Map unit name to SI
 UNIT_MAP = {
@@ -62,7 +54,7 @@ class InvalidSensorData(ValueError):
     pass
 
 
-class SensorNotification(plugin_base.NotificationBase):
+class SensorNotification(endpoint.SampleEndpoint):
     """A generic class for extracting samples from sensor data notifications.
 
     A notification message can contain multiple samples from multiple
@@ -76,12 +68,6 @@ class SensorNotification(plugin_base.NotificationBase):
     event_types = ['hardware.ipmi.*']
     metric = None
 
-    def get_targets(self, conf):
-        """oslo.messaging.TargetS for this plugin."""
-        return [messaging.Target(topic=topic,
-                                 exchange=conf.ironic_exchange)
-                for topic in self.get_notification_topics(conf)]
-
     def _get_sample(self, message):
         try:
             return (payload for _, payload
@@ -104,7 +90,7 @@ class SensorNotification(plugin_base.NotificationBase):
                 'payload': payload}
         return info
 
-    def process_notification(self, message):
+    def build_sample(self, message):
         """Read and process a notification.
 
         The guts of a message are in dict value of a 'payload' key
