@@ -13,8 +13,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import json
+
 from oslo_log import log
-from oslo_serialization import jsonutils
 from oslo_utils import strutils
 import requests
 from requests import adapters
@@ -154,7 +155,7 @@ class HttpPublisher(publisher.ConfigPublisherBase):
         if not data:
             LOG.debug('Data set is empty!')
             return
-        data = jsonutils.dumps(data)
+        data = json.dumps(data)
         LOG.trace('Message: %s', data)
         try:
             res = self.session.post(self.target, data=data,
