@@ -13,11 +13,11 @@
 # under the License.
 
 import mock
-from oslo_config import fixture as fixture_config
 from oslotest import base
 from six.moves.urllib import parse as urlparse
 
 from ceilometer.network.statistics.opencontrail import driver
+from ceilometer import service
 
 
 class TestOpencontrailDriver(base.BaseTestCase):
@@ -30,7 +30,7 @@ class TestOpencontrailDriver(base.BaseTestCase):
                                    return_value=self.fake_ports())
         self.nc_ports.start()
 
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.CONF = service.prepare_service([], [])
         self.driver = driver.OpencontrailDriver(self.CONF)
         self.parse_url = urlparse.ParseResult('opencontrail',
                                               '127.0.0.1:8143',
@@ -137,7 +137,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'if_stats_list'},),
+                      'resource': 'if_stats_list'},
+                     None),
                     (13,
                      '96d49cc3-4e01-40ce-9cac-c0e32642a442',
                      {'device_owner_id':
@@ -146,7 +147,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'if_stats_list'},)]
+                      'resource': 'if_stats_list'},
+                     None)]
         self._test_meter('switch.port.receive.packets', expected,
                          self.fake_port_stats_with_node())
 
@@ -159,7 +161,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'if_stats_list'},)]
+                      'resource': 'if_stats_list'},
+                     None)]
         self._test_meter('switch.port.receive.packets', expected)
 
     def test_switch_port_transmit_packets(self):
@@ -171,7 +174,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'if_stats_list'},)]
+                      'resource': 'if_stats_list'},
+                     None)]
         self._test_meter('switch.port.transmit.packets', expected)
 
     def test_switch_port_receive_bytes(self):
@@ -183,7 +187,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'if_stats_list'},)]
+                      'resource': 'if_stats_list'},
+                     None)]
         self._test_meter('switch.port.receive.bytes', expected)
 
     def test_switch_port_transmit_bytes(self):
@@ -195,7 +200,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'if_stats_list'},)]
+                      'resource': 'if_stats_list'},
+                     None)]
         self._test_meter('switch.port.transmit.bytes', expected)
 
     def test_switch_port_receive_packets_fip(self):
@@ -208,7 +214,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'fip_stats_list'},)]
+                      'resource': 'fip_stats_list'},
+                     None)]
         self._test_meter('switch.port.receive.packets', expected)
 
     def test_switch_port_transmit_packets_fip(self):
@@ -221,7 +228,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'fip_stats_list'},)]
+                      'resource': 'fip_stats_list'},
+                     None)]
         self._test_meter('switch.port.transmit.packets', expected)
 
     def test_switch_port_receive_bytes_fip(self):
@@ -234,7 +242,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'fip_stats_list'},)]
+                      'resource': 'fip_stats_list'},
+                     None)]
         self._test_meter('switch.port.receive.bytes', expected)
 
     def test_switch_port_transmit_bytes_fip(self):
@@ -247,7 +256,8 @@ class TestOpencontrailDriver(base.BaseTestCase):
                       'network_id': '298a3088-a446-4d5a-bad8-f92ecacd786b',
                       'project': 'demo',
                       'project_id': '89271fa581ab4380bf172f868c3615f9',
-                      'resource': 'fip_stats_list'},)]
+                      'resource': 'fip_stats_list'},
+                     None)]
         self._test_meter('switch.port.transmit.bytes', expected)
 
     def test_switch_port_transmit_bytes_non_existing_network(self):
