@@ -20,7 +20,7 @@ from oslo_log import log
 from oslo_utils import timeutils
 import six
 
-from ceilometer.i18n import _, _LW
+from ceilometer.i18n import _
 from ceilometer import sample
 from ceilometer import transformer
 
@@ -83,19 +83,19 @@ class DeltaTransformer(BaseConversionTransformer):
             time_delta = timeutils.delta_seconds(prev_timestamp, timestamp)
             # disallow violations of the arrow of time
             if time_delta < 0:
-                LOG.warning(_LW('Dropping out of time order sample: %s'), (s,))
+                LOG.warning('Dropping out of time order sample: %s', (s,))
                 # Reset the cache to the newer sample.
                 self.cache[key] = prev
                 return None
             volume_delta = s.volume - prev_volume
             if self.growth_only and volume_delta < 0:
-                LOG.warning(_LW('Negative delta detected, dropping value'))
+                LOG.warning('Negative delta detected, dropping value')
                 s = None
             else:
                 s = self._convert(s, volume_delta)
                 LOG.debug('Converted to: %s', s)
         else:
-            LOG.warning(_LW('Dropping sample with no predecessor: %s'), (s,))
+            LOG.warning('Dropping sample with no predecessor: %s', (s,))
             s = None
         return s
 
